==> cuidai_plugin-1.2.3.tar.gz: ios/Classes/SwiftCuidaiPlugin.swift <==
import Flutter
import UIKit
import CDIMeet
import CDIPlatform
import CDIKit
import CDIFoundation

private enum CuidaiCommand: String {
    case initSDK
    case test
    case route
    case setUserProperty
    case cleanUserProperties
    case setUserProperties
    case logout
}

extension URL {
    func valueOf(_ queryParamaterName: String) -> String? {
        guard let url = URLComponents(string: self.absoluteString) else { return nil }
        return url.queryItems?.first(where: { $0.name == queryParamaterName })?.value
    }
}

public extension Notification.Name {
    struct Interceptor {
        public static let FlutterWillAppear = Notification.Name(rawValue: "app.cuidai.interceptor.flutter.willAppear")
    }
}

extension FlutterViewController {
    @objc dynamic func _swizzled_viewWillAppear(_ animated: Bool) {
        _swizzled_viewWillAppear(animated)
        NotificationCenter.default.post(
            name: Notification.Name.Interceptor.FlutterWillAppear,
            object: nil
        )
    }
}

public class SwiftCuidaiPlugin: NSObject, FlutterPlugin, FlutterApplicationLifeCycleDelegate {

    private var channelFromNative: FlutterMethodChannel? = nil
    private var sdkIsOpen: Bool = false
    
    public override init() {
        let window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
        let controller : FlutterViewController = window.rootViewController as! FlutterViewController
        
        
        self.channelFromNative = FlutterMethodChannel(name: "cuidai_plugin_native", binaryMessenger: controller.binaryMessenger)
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "cuidai_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftCuidaiPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
        registrar.addApplicationDelegate(instance)
        Swizzling.swizzleMethod(
            FlutterViewController.self,
            from: #selector(FlutterViewController.viewWillAppear),
            to: #selector(FlutterViewController._swizzled_viewWillAppear(_:)),
            isClassMethod: false
        )
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        guard let command = CuidaiCommand(rawValue: call.method) else {
            return
        }
        
        switch command {
        
        case .initSDK:
            
            registerNotifications()
            
            guard let map = call.arguments as? [String: Any],
                  let appName = map["appName"] as? String
            else {
                return
            }
            
            Cuidai.instantiate(
                scheme: appName,
                appearance: CDITheme(),
                authenticator: { () -> String in
                    return ""
                },
                subscriber: {
                    return true
                },
                tagger: { (tags) in
                    #if DEBUG
                    print("SDK tags \(tags)")
                    #endif
                },
                router: { (route) in
                    #if DEBUG
                    print("SDK route \(route)")
                    #endif
                    if route.contains("external") {
                        if let newURL = URL(string: route) {
                            let flutterRoute:String = newURL.valueOf("route") ?? "empty"
                            self.channelFromNative?.invokeMethod("route", arguments: ["route": flutterRoute])
                        }
                    }
                    else if route.contains("/call") {
                        let meetUrl = route.replacingOccurrences(of: "vitat://", with: "")
                        let window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
                        let controller : FlutterViewController = window.rootViewController as! FlutterViewController
                        Meet.sharedInstance.openByUrl(meetUrl, controller)
                    }
                }
            )
            
        case .test:
            guard
                let map = call.arguments as? [String: Any],
                let route = map["route"] as? String
            else {
                return
            }
            self.channelFromNative?.invokeMethod("route", arguments: ["route": route])
            
        case .setUserProperty:
            guard
                let map = call.arguments as? [String: Any],
                let key = map["key"] as? String
            else {
                return
            }
            
            let value: String? = map["value"] as? String
            Cuidai.setUserProperty(key: key, value: value)
            
        case .cleanUserProperties:
            Cuidai.cleanUserProperties()
            
        case .logout:
            Cuidai.logout()
            
        case .setUserProperties:
            guard
                let map = call.arguments as? [String: Any],
                let properties = map["properties"] as? [String: String?]
            else {
                return
            }
            
            properties.forEach { (key: String, value: String?) in
                Cuidai.setUserProperty(key: key, value: value)
            }
            
        case .route:
            guard
                let map = call.arguments as? [String: Any],
                let route = map["route"] as? String,
                let params = map["params"] as? [String: Any]
            else {
                return
            }
            
            self.sdkIsOpen = true
            debugPrint("SDK open on Route = [\(self.sdkIsOpen)]")
            debugPrint("SDK open -> \(route)")
            
            Cuidai.openWithParams(route, params)
            
        }
    }
    
    public func applicationDidBecomeActive(_ application: UIApplication) {
        debugPrint("REGIS TRADO")
    }

    public func applicationWillTerminate(_ application: UIApplication) {
        debugPrint("REGIS NAO TRADO")
        unregisterNotifications()
    }

    public func applicationWillResignActive(_ application: UIApplication) {
        debugPrint("applicationWillResignActive")
    }

    public func applicationDidEnterBackground(_ application: UIApplication) {
        debugPrint("applicationDidEnterBackground")
    }

    public func applicationWillEnterForeground(_ application: UIApplication) {
        print("applicationWillEnterForeground")
    }
    
    @objc func willTerminateApplicationOnPlugin(_ notification: Foundation.Notification) {
        Cuidai.route("external?route=updateHome")
    }
    
    @objc func didInterceptPopusOnPlugin(_ notification: Foundation.Notification) {
        guard let popups = notification.object as? [CDIPopup] else {
            return
        }
        
        let popupFlowVC = CDIPopupFlowVC.allocate()
        popupFlowVC.configure(with: popups)
        
        DispatchQueue.main.asyncAfter(deadline: .now() + .milliseconds(350)) {
            let topVC = UIApplication.shared.cdi.topViewController()
            topVC?.present(popupFlowVC, animated: false, completion: {
                print("PopupVC presented")
            })
        }
    }
    
    @objc func didInterceptFlutterWillAppear(_ notification: Foundation.Notification) {
        debugPrint("SDK open on FlutterWillAppear = [\(self.sdkIsOpen)]")
        if self.sdkIsOpen {
            self.sdkIsOpen = false
            self.channelFromNative?.invokeMethod("route", arguments: ["route": "updateHome"])
        }
    }
    
    @objc func didInterceptRouteOnPlugin(_ notification: Foundation.Notification) {
        guard let route = notification.object as? String else {
            return
        }
        
        Cuidai.open(route)
    }
    
    @objc func didInterceptEventsOnPlugin(_ notification: Foundation.Notification) {
        guard let events = notification.object as? [CDIEvent] else {
            return
        }
        
        Cuidai.log(events)
    }
    
    @objc func didInterceptTagsOnPlugin(_ notification: Foundation.Notification) {
        guard let tags = notification.object as? CDITags else {
            return
        }
        
        Cuidai.tag(tags)
    }
    
    public func registerNotifications(_ nc: NotificationCenter = .default) {
        nc.addObserver(
            self,
            selector: #selector(self.willTerminateApplicationOnPlugin(_:)),
            name: UIApplication.willTerminateNotification,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptFlutterWillAppear(_:)),
            name: Notification.Name.Interceptor.FlutterWillAppear,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptPopusOnPlugin(_:)),
            name: Notification.Name.Interceptor.Popups,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptRouteOnPlugin(_:)),
            name: Notification.Name.Interceptor.Route,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptEventsOnPlugin(_:)),
            name: Notification.Name.Interceptor.Events,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptTagsOnPlugin(_:)),
            name: Notification.Name.Interceptor.Tags,
            object: nil
        )
    }
    
    public func unregisterNotifications(_ nc: NotificationCenter = .default) {
        nc.removeObserver(self, name: UIApplication.willTerminateNotification, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Popups, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Route, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Events, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Tags, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.FlutterWillAppear, object: nil)
    }
    
    
}

==> cuidai_plugin-2.0.1.tar.gz: ios/Classes/SwiftCuidaiPlugin.swift <==
import Flutter
import UIKit
import CDIMeet
import CDIPlatform
import CDIKit
import CDIFoundation

private enum CuidaiCommand: String {
    case initSDK
    case test
    case route
    case setUserProperty
    case cleanUserProperties
    case setUserProperties
    case logout
}

extension URL {
    func valueOf(_ queryParamaterName: String) -> String? {
        guard let url = URLComponents(string: self.absoluteString) else { return nil }
        return url.queryItems?.first(where: { $0.name == queryParamaterName })?.value
    }
}

public extension Notification.Name {
    struct Interceptor {
        public static let FlutterWillAppear = Notification.Name(rawValue: "app.cuidai.interceptor.flutter.willAppear")
    }
}

extension FlutterViewController {
    @objc dynamic func _swizzled_viewWillAppear(_ animated: Bool) {
        _swizzled_viewWillAppear(animated)
        NotificationCenter.default.post(
            name: Notification.Name.Interceptor.FlutterWillAppear,
            object: nil
        )
    }
}

public class SwiftCuidaiPlugin: NSObject, FlutterPlugin, FlutterApplicationLifeCycleDelegate {

    private var channelFromNative: FlutterMethodChannel? = nil
    private var sdkIsOpen: Bool = false
    
    public override init() {
        let window: UIWindow = ((UIApplication.shared.delegate?.window)!)!
        let controller : FlutterViewController = window.rootViewController as! FlutterViewController
        
        
        self.channelFromNative = FlutterMethodChannel(name: "cuidai_plugin_native", binaryMessenger: controller.binaryMessenger)
    }
    
    public static func register(with registrar: FlutterPluginRegistrar) {
        let channel = FlutterMethodChannel(name: "cuidai_plugin", binaryMessenger: registrar.messenger())
        let instance = SwiftCuidaiPlugin()
        registrar.addMethodCallDelegate(instance, channel: channel)
        registrar.addApplicationDelegate(instance)
        Swizzling.swizzleMethod(
            FlutterViewController.self,
            from: #selector(FlutterViewController.viewWillAppear),
            to: #selector(FlutterViewController._swizzled_viewWillAppear(_:)),
            isClassMethod: false
        )
    }
    
    public func handle(_ call: FlutterMethodCall, result: @escaping FlutterResult) {
        
        guard let command = CuidaiCommand(rawValue: call.method) else {
            return
        }
        
        switch command {
        
        case .initSDK:
            
            registerNotifications()
            
            guard let map = call.arguments as? [String: Any],
                  let appName = map["appName"] as? String
            else {
                return
            }
            
            Cuidai.instantiate(
                scheme: appName,
                appearance: CDITheme(),
                authenticator: { () -> String in
                    return ""
                },
                subscriber: {
                    return true
                },
                tagger: { (tags) in
                    #if DEBUG
                    print("SDK tags \(tags)")
                    #endif
                },
                router: { (route) in
                    #if DEBUG
                    print("SDK route \(route)")
                    #endif
                    if route.contains("external") {
                        if let newURL = URL(string: route) {
                            let flutterRoute:String = newURL.valueOf("route") ?? "empty"
                            self.channelFromNative?.invokeMethod("route", arguments: ["route": flutterRoute])
                        }
                    }
                    else if route.contains("/call") {
                        let meetUrl = route.replacingOccurrences(of: "vitat://", with: "")
                        
                        if var topController = UIApplication.shared.keyWindow?.rootViewController {
                            while let presentedViewController = topController.presentedViewController {
                                topController = presentedViewController
                            }
                            debugPrint("meet-> window is valid")
                            debugPrint("meet-> VC is valid \(topController)")
                            Meet.sharedInstance.openByUrl(meetUrl, topController)
                        }
                        
                    }
                }
            )
            
        case .test:
            guard
                let map = call.arguments as? [String: Any],
                let route = map["route"] as? String
            else {
                return
            }
            self.channelFromNative?.invokeMethod("route", arguments: ["route": route])
            
        case .setUserProperty:
            guard
                let map = call.arguments as? [String: Any],
                let key = map["key"] as? String
            else {
                return
            }
            
            let value: String? = map["value"] as? String
            Cuidai.setUserProperty(key: key, value: value)
            
        case .cleanUserProperties:
            Cuidai.cleanUserProperties()
            
        case .logout:
            Cuidai.logout()
            
        case .setUserProperties:
            guard
                let map = call.arguments as? [String: Any],
                let properties = map["properties"] as? [String: String?]
            else {
                return
            }
            
            properties.forEach { (key: String, value: String?) in
                Cuidai.setUserProperty(key: key, value: value)
            }
            
        case .route:
            guard
                let map = call.arguments as? [String: Any],
                let route = map["route"] as? String,
                let params = map["params"] as? [String: Any]
            else {
                return
            }
            
            self.sdkIsOpen = true
            debugPrint("SDK open on Route = [\(self.sdkIsOpen)]")
            debugPrint("SDK open -> \(route)")
            
            Cuidai.openWithParams(route, params)
            
        }
    }
    
    public func applicationDidBecomeActive(_ application: UIApplication) {
        debugPrint("REGIS TRADO")
    }

    public func applicationWillTerminate(_ application: UIApplication) {
        debugPrint("REGIS NAO TRADO")
        unregisterNotifications()
    }

    public func applicationWillResignActive(_ application: UIApplication) {
        debugPrint("applicationWillResignActive")
    }

    public func applicationDidEnterBackground(_ application: UIApplication) {
        debugPrint("applicationDidEnterBackground")
    }

    public func applicationWillEnterForeground(_ application: UIApplication) {
        print("applicationWillEnterForeground")
    }
    
    @objc func willTerminateApplicationOnPlugin(_ notification: Foundation.Notification) {
        Cuidai.route("external?route=updateHome")
    }
    
    @objc func didInterceptPopusOnPlugin(_ notification: Foundation.Notification) {
        guard let popups = notification.object as? [CDIPopup] else {
            return
        }
        
        let popupFlowVC = CDIPopupFlowVC.allocate()
        popupFlowVC.configure(with: popups)
        
        DispatchQueue.main.asyncAfter(deadline: .now() + .milliseconds(350)) {
            let topVC = UIApplication.shared.cdi.topViewController()
            topVC?.present(popupFlowVC, animated: false, completion: {
                print("PopupVC presented")
            })
        }
    }
    
    @objc func didInterceptFlutterWillAppear(_ notification: Foundation.Notification) {
        debugPrint("SDK open on FlutterWillAppear = [\(self.sdkIsOpen)]")
        if self.sdkIsOpen {
            self.sdkIsOpen = false
            self.channelFromNative?.invokeMethod("route", arguments: ["route": "updateHome"])
        }
    }
    
    @objc func didInterceptRouteOnPlugin(_ notification: Foundation.Notification) {
        guard let route = notification.object as? String else {
            return
        }
        
        Cuidai.open(route)
    }
    
    @objc func didInterceptEventsOnPlugin(_ notification: Foundation.Notification) {
        guard let events = notification.object as? [CDIEvent] else {
            return
        }
        
        Cuidai.log(events)
    }
    
    @objc func didInterceptTagsOnPlugin(_ notification: Foundation.Notification) {
        guard let tags = notification.object as? CDITags else {
            return
        }
        
        Cuidai.tag(tags)
    }
    
    public func registerNotifications(_ nc: NotificationCenter = .default) {
        nc.addObserver(
            self,
            selector: #selector(self.willTerminateApplicationOnPlugin(_:)),
            name: UIApplication.willTerminateNotification,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptFlutterWillAppear(_:)),
            name: Notification.Name.Interceptor.FlutterWillAppear,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptPopusOnPlugin(_:)),
            name: Notification.Name.Interceptor.Popups,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptRouteOnPlugin(_:)),
            name: Notification.Name.Interceptor.Route,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptEventsOnPlugin(_:)),
            name: Notification.Name.Interceptor.Events,
            object: nil
        )
        
        nc.addObserver(
            self,
            selector: #selector(self.didInterceptTagsOnPlugin(_:)),
            name: Notification.Name.Interceptor.Tags,
            object: nil
        )
    }
    
    public func unregisterNotifications(_ nc: NotificationCenter = .default) {
        nc.removeObserver(self, name: UIApplication.willTerminateNotification, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Popups, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Route, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Events, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.Tags, object: nil)
        nc.removeObserver(self, name: Notification.Name.Interceptor.FlutterWillAppear, object: nil)
    }
    
    
}
